@@ -1,4 +1,4 @@
-context("biophysmodel_Sceloporus")
+context("biophysmodel_snail")
 
 expect_similar <- function(input, expected) {
   eval(bquote(expect_lt(abs(input - expected), 0.01)))
@@ -7,8 +7,8 @@ expect_similar <- function(input, expected) {
 test_that("Tb_snail function works as expected", {
   expect_similar(Tb_snail(temp  = 25, 
                  l     = 0.012, 
-                 solar = 800, 
-                 WS    = 1, 
+                 S = 800, 
+                 u    = 1, 
                  CC    = 0.5, 
                  WL    = 0, 
                  WSH   = 10), 38.79568)
@@ -19,8 +19,8 @@ test_that("Tb_snail function works as expected", {
 test_that("Tb_snail function works as expected", {
   expect_similar(Tb_snail(temp  = 25, 
                  l     = 0.04, 
-                 solar = 800, 
-                 WS    = 1, 
+                 S = 800, 
+                 u    = 1, 
                  CC    = 0.5, 
                  WL    = 0, 
                  WSH   = 10), 38.44257)
@@ -30,8 +30,8 @@ test_that("Tb_snail function works as expected", {
 test_that("Tb_snail function works as expected", {
   expect_similar(Tb_snail(temp  = 25, 
                  l     = 0.03, 
-                 solar = 800, 
-                 WS    = 1, 
+                 S = 800, 
+                 u    = 1, 
                  CC    = 0.5, 
                  WL    = 0, 
                  WSH   = 10), 39.88404)
